/*
    w32loader
    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
#include "ole32.h"


#ifdef W32LDR_HEADER
#include "pshpack1.h"
#define S_OK 0
#define S_FALSE 1
#define E_FAIL 0x80004005
#define CLASS_E_NOAGGREGATION 0x80040110L
#define TYPE_E_LIBNOTREGISTERED 0x8002801d
typedef struct _GUID
{
  LONG Data1;
  SHORT Data2;
  SHORT Data3;
  CHAR Data4[8];
} GUID, *LPGUID, CLSID, *LPCLSID, IID, *LPIID, FMTID, *LPFMTID;
#include "poppack.h"
typedef LONG HRESULT;
typedef VOID *LPUNKNOWN;
typedef WCHAR OLECHAR;
typedef LPWSTR LPOLESTR;
typedef LPCWSTR LPCOLESTR;
#define REFGUID  const GUID* const
#define REFCLSID const CLSID* const
#define REFIID   const IID* const
#define REFFMTID const FMTID* const
#endif /* W32LDR_HEADER */


/* BindMoniker ordinal = 9, argument = 16 temporary */
static DWORD WINAPI BindMoniker (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* CLIPFORMAT_UserFree ordinal = 10, argument = 8 temporary */
static DWORD WINAPI CLIPFORMAT_UserFree (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CLIPFORMAT_UserMarshal ordinal = 11, argument = 12 temporary */
static DWORD WINAPI CLIPFORMAT_UserMarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* CLIPFORMAT_UserSize ordinal = 12, argument = 12 temporary */
static DWORD WINAPI CLIPFORMAT_UserSize (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* CLIPFORMAT_UserUnmarshal ordinal = 13, argument = 12 temporary */
static DWORD WINAPI CLIPFORMAT_UserUnmarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* CLSIDFromOle1Class ordinal = 14, argument = 0 temporary */
static DWORD WINAPI CLSIDFromOle1Class (VOID)
{
  return 0;
}


/* CLSIDFromProgID ordinal = 15, argument = 8 temporary */
static DWORD WINAPI CLSIDFromProgID (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CLSIDFromProgIDEx ordinal = 16, argument = 8 temporary */
static DWORD WINAPI CLSIDFromProgIDEx (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CLSIDFromString ordinal = 17, argument = 8 temporary */
static DWORD WINAPI CLSIDFromString (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoAddRefServerProcess ordinal = 18, argument = 0 temporary */
static DWORD WINAPI CoAddRefServerProcess (VOID)
{
  return 0;
}


/* CoAllowSetForegroundWindow ordinal = 19, argument = 8 temporary */
static DWORD WINAPI CoAllowSetForegroundWindow (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoBuildVersion ordinal = 20, argument = 0 temporary */
static DWORD WINAPI CoBuildVersion (VOID)
{
  return 0;
}


/* CoCancelCall ordinal = 21, argument = 8 temporary */
static DWORD WINAPI CoCancelCall (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoCopyProxy ordinal = 22, argument = 8 temporary */
static DWORD WINAPI CoCopyProxy (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoCreateFreeThreadedMarshaler ordinal = 23, argument = 8 temporary */
static DWORD WINAPI CoCreateFreeThreadedMarshaler (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoCreateGuid ordinal = 24, argument = 4 temporary */
static DWORD WINAPI CoCreateGuid (DWORD dwArgv0)
{
  return 0;
}


/* CoCreateInstance ordinal = 25, argument = 20 */
HRESULT WINAPI CoCreateInstance (REFCLSID rclsid, LPUNKNOWN pUnkOuter, DWORD dwClsContext, REFIID iid, LPVOID *ppv)
{
  return CLASS_E_NOAGGREGATION;
}


/* CoCreateInstanceEx ordinal = 26, argument = 24 temporary */
static DWORD WINAPI CoCreateInstanceEx (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5)
{
  return 0;
}


/* CoCreateObjectInContext ordinal = 27, argument = 16 temporary */
static DWORD WINAPI CoCreateObjectInContext (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* CoDeactivateObject ordinal = 28, argument = 8 temporary */
static DWORD WINAPI CoDeactivateObject (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoDisableCallCancellation ordinal = 29, argument = 4 temporary */
static DWORD WINAPI CoDisableCallCancellation (DWORD dwArgv0)
{
  return 0;
}


/* CoDisconnectObject ordinal = 30, argument = 8 temporary */
static DWORD WINAPI CoDisconnectObject (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoDosDateTimeToFileTime ordinal = 31, argument = 12 temporary */
static DWORD WINAPI CoDosDateTimeToFileTime (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* CoEnableCallCancellation ordinal = 32, argument = 4 temporary */
static DWORD WINAPI CoEnableCallCancellation (DWORD dwArgv0)
{
  return 0;
}


/* CoFileTimeNow ordinal = 33, argument = 4 temporary */
static DWORD WINAPI CoFileTimeNow (DWORD dwArgv0)
{
  return 0;
}


/* CoFileTimeToDosDateTime ordinal = 34, argument = 12 temporary */
static DWORD WINAPI CoFileTimeToDosDateTime (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* CoFreeAllLibraries ordinal = 35, argument = 0 temporary */
static DWORD WINAPI CoFreeAllLibraries (VOID)
{
  return 0;
}


/* CoFreeLibrary ordinal = 36, argument = 4 temporary */
static DWORD WINAPI CoFreeLibrary (DWORD dwArgv0)
{
  return 0;
}


/* CoFreeUnusedLibraries ordinal = 37, argument = 0 */
void WINAPI CoFreeUnusedLibraries (void)
{
}


/* CoFreeUnusedLibrariesEx ordinal = 38, argument = 8 temporary */
static DWORD WINAPI CoFreeUnusedLibrariesEx (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoGetApartmentID ordinal = 39, argument = 8 temporary */
static DWORD WINAPI CoGetApartmentID (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoGetCallContext ordinal = 40, argument = 8 temporary */
static DWORD WINAPI CoGetCallContext (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoGetCallerTID ordinal = 41, argument = 4 temporary */
static DWORD WINAPI CoGetCallerTID (DWORD dwArgv0)
{
  return 0;
}


/* CoGetCancelObject ordinal = 42, argument = 12 temporary */
static DWORD WINAPI CoGetCancelObject (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* CoGetClassObject ordinal = 43, argument = 20 temporary */
static DWORD WINAPI CoGetClassObject (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4)
{
  return 0;
}


/* CoGetClassVersion ordinal = 44, argument = 12 temporary */
static DWORD WINAPI CoGetClassVersion (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* CoGetContextToken ordinal = 45, argument = 4 temporary */
static DWORD WINAPI CoGetContextToken (DWORD dwArgv0)
{
  return 0;
}


/* CoGetCurrentLogicalThreadId ordinal = 46, argument = 4 temporary */
static DWORD WINAPI CoGetCurrentLogicalThreadId (DWORD dwArgv0)
{
  return 0;
}


/* CoGetCurrentProcess ordinal = 47, argument = 0 temporary */
static DWORD WINAPI CoGetCurrentProcess (VOID)
{
  return 0;
}


/* CoGetInstanceFromFile ordinal = 48, argument = 32 temporary */
static DWORD WINAPI CoGetInstanceFromFile (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5, DWORD dwArgv6, DWORD dwArgv7)
{
  return 0;
}


/* CoGetInstanceFromIStorage ordinal = 49, argument = 28 temporary */
static DWORD WINAPI CoGetInstanceFromIStorage (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5, DWORD dwArgv6)
{
  return 0;
}


/* CoGetInterfaceAndReleaseStream ordinal = 50, argument = 12 temporary */
static DWORD WINAPI CoGetInterfaceAndReleaseStream (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* CoGetMalloc ordinal = 51, argument = 8 temporary */
static DWORD WINAPI CoGetMalloc (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoGetMarshalSizeMax ordinal = 52, argument = 24 temporary */
static DWORD WINAPI CoGetMarshalSizeMax (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5)
{
  return 0;
}


/* CoGetObject ordinal = 53, argument = 16 temporary */
static DWORD WINAPI CoGetObject (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* CoGetObjectContext ordinal = 54, argument = 8 temporary */
static DWORD WINAPI CoGetObjectContext (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoGetPSClsid ordinal = 55, argument = 8 temporary */
static DWORD WINAPI CoGetPSClsid (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoGetStandardMarshal ordinal = 56, argument = 24 temporary */
static DWORD WINAPI CoGetStandardMarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5)
{
  return 0;
}


/* CoGetState ordinal = 57, argument = 4 temporary */
static DWORD WINAPI CoGetState (DWORD dwArgv0)
{
  return 0;
}


/* CoGetStdMarshalEx ordinal = 58, argument = 12 temporary */
static DWORD WINAPI CoGetStdMarshalEx (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* CoGetTreatAsClass ordinal = 59, argument = 8 temporary */
static DWORD WINAPI CoGetTreatAsClass (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoImpersonateClient ordinal = 60, argument = 0 temporary */
static DWORD WINAPI CoImpersonateClient (VOID)
{
  return 0;
}


/* CoInitialize ordinal = 61, argument = 4 */
HRESULT WINAPI CoInitialize (LPVOID lpReserved)
{
  return S_FALSE;
}


/* CoInitializeEx ordinal = 62, argument = 8 temporary */
static DWORD WINAPI CoInitializeEx (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoInitializeSecurity ordinal = 63, argument = 36 temporary */
static DWORD WINAPI CoInitializeSecurity (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5, DWORD dwArgv6, DWORD dwArgv7, DWORD dwArgv8)
{
  return 0;
}


/* CoInitializeWOW ordinal = 64, argument = 8 temporary */
static DWORD WINAPI CoInitializeWOW (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoInstall ordinal = 65, argument = 20 temporary */
static DWORD WINAPI CoInstall (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4)
{
  return 0;
}


/* CoIsHandlerConnected ordinal = 66, argument = 4 temporary */
static DWORD WINAPI CoIsHandlerConnected (DWORD dwArgv0)
{
  return 0;
}


/* CoIsOle1Class ordinal = 67, argument = 4 temporary */
static DWORD WINAPI CoIsOle1Class (DWORD dwArgv0)
{
  return 0;
}


/* CoLoadLibrary ordinal = 68, argument = 8 temporary */
static DWORD WINAPI CoLoadLibrary (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoLockObjectExternal ordinal = 69, argument = 12 temporary */
static DWORD WINAPI CoLockObjectExternal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* CoMarshalHresult ordinal = 70, argument = 8 temporary */
static DWORD WINAPI CoMarshalHresult (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoMarshalInterThreadInterfaceInStream ordinal = 71, argument = 12 temporary */
static DWORD WINAPI CoMarshalInterThreadInterfaceInStream (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* CoMarshalInterface ordinal = 72, argument = 24 temporary */
static DWORD WINAPI CoMarshalInterface (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5)
{
  return 0;
}


/* CoQueryAuthenticationServices ordinal = 73, argument = 8 temporary */
static DWORD WINAPI CoQueryAuthenticationServices (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoQueryClientBlanket ordinal = 74, argument = 28 temporary */
static DWORD WINAPI CoQueryClientBlanket (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5, DWORD dwArgv6)
{
  return 0;
}


/* CoQueryProxyBlanket ordinal = 75, argument = 32 temporary */
static DWORD WINAPI CoQueryProxyBlanket (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5, DWORD dwArgv6, DWORD dwArgv7)
{
  return 0;
}


/* CoQueryReleaseObject ordinal = 76, argument = 4 temporary */
static DWORD WINAPI CoQueryReleaseObject (DWORD dwArgv0)
{
  return 0;
}


/* CoReactivateObject ordinal = 77, argument = 8 temporary */
static DWORD WINAPI CoReactivateObject (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoRegisterChannelHook ordinal = 78, argument = 8 temporary */
static DWORD WINAPI CoRegisterChannelHook (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoRegisterClassObject ordinal = 79, argument = 20 temporary */
static DWORD WINAPI CoRegisterClassObject (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4)
{
  return 0;
}


/* CoRegisterMallocSpy ordinal = 80, argument = 4 temporary */
static DWORD WINAPI CoRegisterMallocSpy (DWORD dwArgv0)
{
  return 0;
}


/* CoRegisterMessageFilter ordinal = 81, argument = 8 temporary */
static DWORD WINAPI CoRegisterMessageFilter (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoRegisterPSClsid ordinal = 82, argument = 8 temporary */
static DWORD WINAPI CoRegisterPSClsid (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoRegisterSurrogate ordinal = 83, argument = 4 temporary */
static DWORD WINAPI CoRegisterSurrogate (DWORD dwArgv0)
{
  return 0;
}


/* CoRegisterSurrogateEx ordinal = 84, argument = 8 temporary */
static DWORD WINAPI CoRegisterSurrogateEx (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoReleaseMarshalData ordinal = 85, argument = 4 temporary */
static DWORD WINAPI CoReleaseMarshalData (DWORD dwArgv0)
{
  return 0;
}


/* CoReleaseServerProcess ordinal = 86, argument = 0 temporary */
static DWORD WINAPI CoReleaseServerProcess (VOID)
{
  return 0;
}


/* CoResumeClassObjects ordinal = 87, argument = 0 temporary */
static DWORD WINAPI CoResumeClassObjects (VOID)
{
  return 0;
}


/* CoRevertToSelf ordinal = 88, argument = 0 temporary */
static DWORD WINAPI CoRevertToSelf (VOID)
{
  return 0;
}


/* CoRevokeClassObject ordinal = 89, argument = 4 temporary */
static DWORD WINAPI CoRevokeClassObject (DWORD dwArgv0)
{
  return 0;
}


/* CoRevokeMallocSpy ordinal = 90, argument = 0 temporary */
static DWORD WINAPI CoRevokeMallocSpy (VOID)
{
  return 0;
}


/* CoSetCancelObject ordinal = 91, argument = 4 temporary */
static DWORD WINAPI CoSetCancelObject (DWORD dwArgv0)
{
  return 0;
}


/* CoSetProxyBlanket ordinal = 92, argument = 32 temporary */
static DWORD WINAPI CoSetProxyBlanket (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5, DWORD dwArgv6, DWORD dwArgv7)
{
  return 0;
}


/* CoSetState ordinal = 93, argument = 4 temporary */
static DWORD WINAPI CoSetState (DWORD dwArgv0)
{
  return 0;
}


/* CoSuspendClassObjects ordinal = 94, argument = 0 temporary */
static DWORD WINAPI CoSuspendClassObjects (VOID)
{
  return 0;
}


/* CoSwitchCallContext ordinal = 95, argument = 8 temporary */
static DWORD WINAPI CoSwitchCallContext (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoTaskMemAlloc ordinal = 96, argument = 4 */
LPVOID WINAPI CoTaskMemAlloc (ULONG size)
{
  return NULL;
}


/* CoTaskMemFree ordinal = 97, argument = 4 */
void WINAPI CoTaskMemFree (LPVOID ptr)
{
}


/* CoTaskMemRealloc ordinal = 98, argument = 8 temporary */
static DWORD WINAPI CoTaskMemRealloc (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoTestCancel ordinal = 99, argument = 0 temporary */
static DWORD WINAPI CoTestCancel (VOID)
{
  return 0;
}


/* CoTreatAsClass ordinal = 100, argument = 8 temporary */
static DWORD WINAPI CoTreatAsClass (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoUninitialize ordinal = 101, argument = 0 */
void WINAPI CoUninitialize (void)
{
}


/* CoUnloadingWOW ordinal = 102, argument = 4 temporary */
static DWORD WINAPI CoUnloadingWOW (DWORD dwArgv0)
{
  return 0;
}


/* CoUnmarshalHresult ordinal = 103, argument = 8 temporary */
static DWORD WINAPI CoUnmarshalHresult (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CoUnmarshalInterface ordinal = 104, argument = 12 temporary */
static DWORD WINAPI CoUnmarshalInterface (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* CoWaitForMultipleHandles ordinal = 105, argument = 20 temporary */
static DWORD WINAPI CoWaitForMultipleHandles (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4)
{
  return 0;
}


/* CreateAntiMoniker ordinal = 106, argument = 4 temporary */
static DWORD WINAPI CreateAntiMoniker (DWORD dwArgv0)
{
  return 0;
}


/* CreateBindCtx ordinal = 107, argument = 8 temporary */
static DWORD WINAPI CreateBindCtx (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CreateClassMoniker ordinal = 108, argument = 8 temporary */
static DWORD WINAPI CreateClassMoniker (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CreateDataAdviseHolder ordinal = 109, argument = 4 temporary */
static DWORD WINAPI CreateDataAdviseHolder (DWORD dwArgv0)
{
  return 0;
}


/* CreateDataCache ordinal = 110, argument = 16 temporary */
static DWORD WINAPI CreateDataCache (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* CreateErrorInfo ordinal = 111, argument = 0 temporary,conflict */
static DWORD WINAPI ole32_CreateErrorInfo (VOID)
{
  return 0;
}


/* CreateFileMoniker ordinal = 112, argument = 8 temporary */
static DWORD WINAPI CreateFileMoniker (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CreateGenericComposite ordinal = 113, argument = 12 temporary */
static DWORD WINAPI CreateGenericComposite (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* CreateILockBytesOnHGlobal ordinal = 114, argument = 12 temporary */
static DWORD WINAPI CreateILockBytesOnHGlobal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* CreateItemMoniker ordinal = 115, argument = 12 temporary */
static DWORD WINAPI CreateItemMoniker (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* CreateObjrefMoniker ordinal = 116, argument = 8 temporary */
static DWORD WINAPI CreateObjrefMoniker (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CreateOleAdviseHolder ordinal = 117, argument = 4 temporary */
static DWORD WINAPI CreateOleAdviseHolder (DWORD dwArgv0)
{
  return 0;
}


/* CreatePointerMoniker ordinal = 118, argument = 8 temporary */
static DWORD WINAPI CreatePointerMoniker (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* CreateStdProgressIndicator ordinal = 119, argument = 16 temporary */
static DWORD WINAPI CreateStdProgressIndicator (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* CreateStreamOnHGlobal ordinal = 120, argument = 12 temporary */
static DWORD WINAPI CreateStreamOnHGlobal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* DcomChannelSetHResult ordinal = 121, argument = 12 temporary */
static DWORD WINAPI DcomChannelSetHResult (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* DllDebugObjectRPCHook ordinal = 122, argument = 8 temporary */
static DWORD WINAPI DllDebugObjectRPCHook (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* DllGetClassObject ordinal = 123, argument = 0 temporary,conflict */
static DWORD WINAPI ole32_DllGetClassObject (VOID)
{
  return 0;
}


/* DllGetClassObjectWOW ordinal = 124, argument = 12 temporary */
static DWORD WINAPI DllGetClassObjectWOW (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* DllRegisterServer ordinal = 125, argument = 0 temporary,conflict */
static DWORD WINAPI ole32_DllRegisterServer (VOID)
{
  return 0;
}


/* DoDragDrop ordinal = 126, argument = 16 temporary */
static DWORD WINAPI DoDragDrop (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* EnableHookObject ordinal = 127, argument = 8 temporary */
static DWORD WINAPI EnableHookObject (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* FmtIdToPropStgName ordinal = 128, argument = 8 temporary */
static DWORD WINAPI FmtIdToPropStgName (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* FreePropVariantArray ordinal = 129, argument = 8 temporary */
static DWORD WINAPI FreePropVariantArray (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* GetClassFile ordinal = 130, argument = 8 temporary */
static DWORD WINAPI GetClassFile (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* GetConvertStg ordinal = 131, argument = 4 temporary */
static DWORD WINAPI GetConvertStg (DWORD dwArgv0)
{
  return 0;
}


/* GetDocumentBitStg ordinal = 132, argument = 4 temporary */
static DWORD WINAPI GetDocumentBitStg (DWORD dwArgv0)
{
  return 0;
}


/* GetErrorInfo ordinal = 133, argument = 0 temporary,conflict */
static DWORD WINAPI ole32_GetErrorInfo (VOID)
{
  return 0;
}


/* GetHGlobalFromILockBytes ordinal = 134, argument = 8 temporary */
static DWORD WINAPI GetHGlobalFromILockBytes (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* GetHGlobalFromStream ordinal = 135, argument = 8 temporary */
static DWORD WINAPI GetHGlobalFromStream (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* GetHookInterface ordinal = 136, argument = 4 temporary */
static DWORD WINAPI GetHookInterface (DWORD dwArgv0)
{
  return 0;
}


/* GetRunningObjectTable ordinal = 137, argument = 8 temporary */
static DWORD WINAPI GetRunningObjectTable (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* HACCEL_UserFree ordinal = 138, argument = 8 temporary */
static DWORD WINAPI HACCEL_UserFree (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* HACCEL_UserMarshal ordinal = 139, argument = 12 temporary */
static DWORD WINAPI HACCEL_UserMarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HACCEL_UserSize ordinal = 140, argument = 12 temporary */
static DWORD WINAPI HACCEL_UserSize (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HACCEL_UserUnmarshal ordinal = 141, argument = 12 temporary */
static DWORD WINAPI HACCEL_UserUnmarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HBITMAP_UserFree ordinal = 142, argument = 8 temporary */
static DWORD WINAPI HBITMAP_UserFree (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* HBITMAP_UserMarshal ordinal = 143, argument = 12 temporary */
static DWORD WINAPI HBITMAP_UserMarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HBITMAP_UserSize ordinal = 144, argument = 12 temporary */
static DWORD WINAPI HBITMAP_UserSize (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HBITMAP_UserUnmarshal ordinal = 145, argument = 12 temporary */
static DWORD WINAPI HBITMAP_UserUnmarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HBRUSH_UserFree ordinal = 146, argument = 8 temporary */
static DWORD WINAPI HBRUSH_UserFree (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* HBRUSH_UserMarshal ordinal = 147, argument = 12 temporary */
static DWORD WINAPI HBRUSH_UserMarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HBRUSH_UserSize ordinal = 148, argument = 12 temporary */
static DWORD WINAPI HBRUSH_UserSize (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HBRUSH_UserUnmarshal ordinal = 149, argument = 12 temporary */
static DWORD WINAPI HBRUSH_UserUnmarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HDC_UserFree ordinal = 150, argument = 8 temporary */
static DWORD WINAPI HDC_UserFree (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* HDC_UserMarshal ordinal = 151, argument = 12 temporary */
static DWORD WINAPI HDC_UserMarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HDC_UserSize ordinal = 152, argument = 12 temporary */
static DWORD WINAPI HDC_UserSize (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HDC_UserUnmarshal ordinal = 153, argument = 12 temporary */
static DWORD WINAPI HDC_UserUnmarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HENHMETAFILE_UserFree ordinal = 154, argument = 8 temporary */
static DWORD WINAPI HENHMETAFILE_UserFree (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* HENHMETAFILE_UserMarshal ordinal = 155, argument = 12 temporary */
static DWORD WINAPI HENHMETAFILE_UserMarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HENHMETAFILE_UserSize ordinal = 156, argument = 12 temporary */
static DWORD WINAPI HENHMETAFILE_UserSize (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HENHMETAFILE_UserUnmarshal ordinal = 157, argument = 12 temporary */
static DWORD WINAPI HENHMETAFILE_UserUnmarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HGLOBAL_UserFree ordinal = 158, argument = 8 temporary */
static DWORD WINAPI HGLOBAL_UserFree (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* HGLOBAL_UserMarshal ordinal = 159, argument = 12 temporary */
static DWORD WINAPI HGLOBAL_UserMarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HGLOBAL_UserSize ordinal = 160, argument = 12 temporary */
static DWORD WINAPI HGLOBAL_UserSize (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HGLOBAL_UserUnmarshal ordinal = 161, argument = 12 temporary */
static DWORD WINAPI HGLOBAL_UserUnmarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HICON_UserFree ordinal = 162, argument = 8 temporary */
static DWORD WINAPI HICON_UserFree (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* HICON_UserMarshal ordinal = 163, argument = 12 temporary */
static DWORD WINAPI HICON_UserMarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HICON_UserSize ordinal = 164, argument = 12 temporary */
static DWORD WINAPI HICON_UserSize (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HICON_UserUnmarshal ordinal = 165, argument = 12 temporary */
static DWORD WINAPI HICON_UserUnmarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HMENU_UserFree ordinal = 166, argument = 8 temporary */
static DWORD WINAPI HMENU_UserFree (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* HMENU_UserMarshal ordinal = 167, argument = 12 temporary */
static DWORD WINAPI HMENU_UserMarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HMENU_UserSize ordinal = 168, argument = 12 temporary */
static DWORD WINAPI HMENU_UserSize (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HMENU_UserUnmarshal ordinal = 169, argument = 12 temporary */
static DWORD WINAPI HMENU_UserUnmarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HMETAFILEPICT_UserFree ordinal = 170, argument = 8 temporary */
static DWORD WINAPI HMETAFILEPICT_UserFree (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* HMETAFILEPICT_UserMarshal ordinal = 171, argument = 12 temporary */
static DWORD WINAPI HMETAFILEPICT_UserMarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HMETAFILEPICT_UserSize ordinal = 172, argument = 12 temporary */
static DWORD WINAPI HMETAFILEPICT_UserSize (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HMETAFILEPICT_UserUnmarshal ordinal = 173, argument = 12 temporary */
static DWORD WINAPI HMETAFILEPICT_UserUnmarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HMETAFILE_UserFree ordinal = 174, argument = 8 temporary */
static DWORD WINAPI HMETAFILE_UserFree (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* HMETAFILE_UserMarshal ordinal = 175, argument = 12 temporary */
static DWORD WINAPI HMETAFILE_UserMarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HMETAFILE_UserSize ordinal = 176, argument = 12 temporary */
static DWORD WINAPI HMETAFILE_UserSize (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HMETAFILE_UserUnmarshal ordinal = 177, argument = 12 temporary */
static DWORD WINAPI HMETAFILE_UserUnmarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HPALETTE_UserFree ordinal = 178, argument = 8 temporary */
static DWORD WINAPI HPALETTE_UserFree (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* HPALETTE_UserMarshal ordinal = 179, argument = 12 temporary */
static DWORD WINAPI HPALETTE_UserMarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HPALETTE_UserSize ordinal = 180, argument = 12 temporary */
static DWORD WINAPI HPALETTE_UserSize (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HPALETTE_UserUnmarshal ordinal = 181, argument = 12 temporary */
static DWORD WINAPI HPALETTE_UserUnmarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HWND_UserFree ordinal = 182, argument = 8 temporary */
static DWORD WINAPI HWND_UserFree (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* HWND_UserMarshal ordinal = 183, argument = 12 temporary */
static DWORD WINAPI HWND_UserMarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HWND_UserSize ordinal = 184, argument = 12 temporary */
static DWORD WINAPI HWND_UserSize (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HWND_UserUnmarshal ordinal = 185, argument = 12 temporary */
static DWORD WINAPI HWND_UserUnmarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* HkOleRegisterObject ordinal = 186, argument = 16 temporary */
static DWORD WINAPI HkOleRegisterObject (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* IIDFromString ordinal = 187, argument = 8 temporary */
static DWORD WINAPI IIDFromString (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* IsAccelerator ordinal = 188, argument = 16 temporary */
static DWORD WINAPI IsAccelerator (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* IsEqualGUID ordinal = 189, argument = 8 temporary */
static DWORD WINAPI IsEqualGUID (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* IsValidIid ordinal = 190, argument = 4 temporary */
static DWORD WINAPI IsValidIid (DWORD dwArgv0)
{
  return 0;
}


/* IsValidInterface ordinal = 191, argument = 4 temporary */
static DWORD WINAPI IsValidInterface (DWORD dwArgv0)
{
  return 0;
}


/* IsValidPtrIn ordinal = 192, argument = 8 temporary */
static DWORD WINAPI IsValidPtrIn (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* IsValidPtrOut ordinal = 193, argument = 8 temporary */
static DWORD WINAPI IsValidPtrOut (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* MkParseDisplayName ordinal = 194, argument = 16 temporary */
static DWORD WINAPI MkParseDisplayName (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* MonikerCommonPrefixWith ordinal = 195, argument = 12 temporary */
static DWORD WINAPI MonikerCommonPrefixWith (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* MonikerRelativePathTo ordinal = 196, argument = 16 temporary */
static DWORD WINAPI MonikerRelativePathTo (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* OleBuildVersion ordinal = 197, argument = 0 temporary */
static DWORD WINAPI OleBuildVersion (VOID)
{
  return 0;
}


/* OleConvertIStorageToOLESTREAM ordinal = 198, argument = 8 temporary */
static DWORD WINAPI OleConvertIStorageToOLESTREAM (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* OleConvertIStorageToOLESTREAMEx ordinal = 199, argument = 28 temporary */
static DWORD WINAPI OleConvertIStorageToOLESTREAMEx (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5, DWORD dwArgv6)
{
  return 0;
}


/* OleConvertOLESTREAMToIStorage ordinal = 200, argument = 12 temporary */
static DWORD WINAPI OleConvertOLESTREAMToIStorage (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* OleConvertOLESTREAMToIStorageEx ordinal = 201, argument = 28 temporary */
static DWORD WINAPI OleConvertOLESTREAMToIStorageEx (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5, DWORD dwArgv6)
{
  return 0;
}


/* OleCreate ordinal = 202, argument = 28 temporary */
static DWORD WINAPI OleCreate (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5, DWORD dwArgv6)
{
  return 0;
}


/* OleCreateDefaultHandler ordinal = 203, argument = 16 temporary */
static DWORD WINAPI OleCreateDefaultHandler (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* OleCreateEmbeddingHelper ordinal = 204, argument = 24 temporary */
static DWORD WINAPI OleCreateEmbeddingHelper (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5)
{
  return 0;
}


/* OleCreateEx ordinal = 205, argument = 48 temporary */
static DWORD WINAPI OleCreateEx (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5, DWORD dwArgv6, DWORD dwArgv7, DWORD dwArgv8, DWORD dwArgv9, DWORD dwArgv10, DWORD dwArgv11)
{
  return 0;
}


/* OleCreateFromData ordinal = 206, argument = 28 temporary */
static DWORD WINAPI OleCreateFromData (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5, DWORD dwArgv6)
{
  return 0;
}


/* OleCreateFromDataEx ordinal = 207, argument = 48 temporary */
static DWORD WINAPI OleCreateFromDataEx (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5, DWORD dwArgv6, DWORD dwArgv7, DWORD dwArgv8, DWORD dwArgv9, DWORD dwArgv10, DWORD dwArgv11)
{
  return 0;
}


/* OleCreateFromFile ordinal = 208, argument = 32 temporary */
static DWORD WINAPI OleCreateFromFile (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5, DWORD dwArgv6, DWORD dwArgv7)
{
  return 0;
}


/* OleCreateFromFileEx ordinal = 209, argument = 52 temporary */
static DWORD WINAPI OleCreateFromFileEx (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5, DWORD dwArgv6, DWORD dwArgv7, DWORD dwArgv8, DWORD dwArgv9, DWORD dwArgv10, DWORD dwArgv11, DWORD dwArgv12)
{
  return 0;
}


/* OleCreateLink ordinal = 210, argument = 28 temporary */
static DWORD WINAPI OleCreateLink (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5, DWORD dwArgv6)
{
  return 0;
}


/* OleCreateLinkEx ordinal = 211, argument = 48 temporary */
static DWORD WINAPI OleCreateLinkEx (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5, DWORD dwArgv6, DWORD dwArgv7, DWORD dwArgv8, DWORD dwArgv9, DWORD dwArgv10, DWORD dwArgv11)
{
  return 0;
}


/* OleCreateLinkFromData ordinal = 212, argument = 28 temporary */
static DWORD WINAPI OleCreateLinkFromData (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5, DWORD dwArgv6)
{
  return 0;
}


/* OleCreateLinkFromDataEx ordinal = 213, argument = 48 temporary */
static DWORD WINAPI OleCreateLinkFromDataEx (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5, DWORD dwArgv6, DWORD dwArgv7, DWORD dwArgv8, DWORD dwArgv9, DWORD dwArgv10, DWORD dwArgv11)
{
  return 0;
}


/* OleCreateLinkToFile ordinal = 214, argument = 28 temporary */
static DWORD WINAPI OleCreateLinkToFile (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5, DWORD dwArgv6)
{
  return 0;
}


/* OleCreateLinkToFileEx ordinal = 215, argument = 48 temporary */
static DWORD WINAPI OleCreateLinkToFileEx (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5, DWORD dwArgv6, DWORD dwArgv7, DWORD dwArgv8, DWORD dwArgv9, DWORD dwArgv10, DWORD dwArgv11)
{
  return 0;
}


/* OleCreateMenuDescriptor ordinal = 216, argument = 8 temporary */
static DWORD WINAPI OleCreateMenuDescriptor (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* OleCreateStaticFromData ordinal = 217, argument = 28 temporary */
static DWORD WINAPI OleCreateStaticFromData (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5, DWORD dwArgv6)
{
  return 0;
}


/* OleDestroyMenuDescriptor ordinal = 218, argument = 4 temporary */
static DWORD WINAPI OleDestroyMenuDescriptor (DWORD dwArgv0)
{
  return 0;
}


/* OleDoAutoConvert ordinal = 219, argument = 8 temporary */
static DWORD WINAPI OleDoAutoConvert (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* OleDraw ordinal = 220, argument = 16 temporary */
static DWORD WINAPI OleDraw (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* OleDuplicateData ordinal = 221, argument = 12 temporary */
static DWORD WINAPI OleDuplicateData (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* OleFlushClipboard ordinal = 222, argument = 0 temporary */
static DWORD WINAPI OleFlushClipboard (VOID)
{
  return 0;
}


/* OleGetAutoConvert ordinal = 223, argument = 8 temporary */
static DWORD WINAPI OleGetAutoConvert (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* OleGetClipboard ordinal = 224, argument = 4 temporary */
static DWORD WINAPI OleGetClipboard (DWORD dwArgv0)
{
  return 0;
}


/* OleGetIconOfClass ordinal = 225, argument = 12 temporary */
static DWORD WINAPI OleGetIconOfClass (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* OleGetIconOfFile ordinal = 226, argument = 8 temporary */
static DWORD WINAPI OleGetIconOfFile (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* OleInitialize ordinal = 227, argument = 4 temporary */
static DWORD WINAPI OleInitialize (DWORD dwArgv0)
{
  return 0;
}


/* OleInitializeWOW ordinal = 228, argument = 8 temporary */
static DWORD WINAPI OleInitializeWOW (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* OleIsCurrentClipboard ordinal = 229, argument = 4 temporary */
static DWORD WINAPI OleIsCurrentClipboard (DWORD dwArgv0)
{
  return 0;
}


/* OleIsRunning ordinal = 230, argument = 4 temporary */
static DWORD WINAPI OleIsRunning (DWORD dwArgv0)
{
  return 0;
}


/* OleLoad ordinal = 231, argument = 16 temporary */
static DWORD WINAPI OleLoad (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* OleLoadFromStream ordinal = 232, argument = 12 temporary */
static DWORD WINAPI OleLoadFromStream (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* OleLockRunning ordinal = 233, argument = 12 temporary */
static DWORD WINAPI OleLockRunning (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* OleMetafilePictFromIconAndLabel ordinal = 234, argument = 16 temporary */
static DWORD WINAPI OleMetafilePictFromIconAndLabel (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* OleNoteObjectVisible ordinal = 235, argument = 8 temporary */
static DWORD WINAPI OleNoteObjectVisible (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* OleQueryCreateFromData ordinal = 236, argument = 4 temporary */
static DWORD WINAPI OleQueryCreateFromData (DWORD dwArgv0)
{
  return 0;
}


/* OleQueryLinkFromData ordinal = 237, argument = 4 temporary */
static DWORD WINAPI OleQueryLinkFromData (DWORD dwArgv0)
{
  return 0;
}


/* OleRegEnumFormatEtc ordinal = 238, argument = 12 temporary */
static DWORD WINAPI OleRegEnumFormatEtc (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* OleRegEnumVerbs ordinal = 239, argument = 8 temporary */
static DWORD WINAPI OleRegEnumVerbs (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* OleRegGetMiscStatus ordinal = 240, argument = 12 temporary */
static DWORD WINAPI OleRegGetMiscStatus (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* OleRegGetUserType ordinal = 241, argument = 12 temporary */
static DWORD WINAPI OleRegGetUserType (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* OleRun ordinal = 242, argument = 4 temporary */
static DWORD WINAPI OleRun (DWORD dwArgv0)
{
  return 0;
}


/* OleSave ordinal = 243, argument = 12 temporary */
static DWORD WINAPI OleSave (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* OleSaveToStream ordinal = 244, argument = 8 temporary */
static DWORD WINAPI OleSaveToStream (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* OleSetAutoConvert ordinal = 245, argument = 8 temporary */
static DWORD WINAPI OleSetAutoConvert (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* OleSetClipboard ordinal = 246, argument = 4 temporary */
static DWORD WINAPI OleSetClipboard (DWORD dwArgv0)
{
  return 0;
}


/* OleSetContainedObject ordinal = 247, argument = 8 temporary */
static DWORD WINAPI OleSetContainedObject (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* OleSetMenuDescriptor ordinal = 248, argument = 20 temporary */
static DWORD WINAPI OleSetMenuDescriptor (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4)
{
  return 0;
}


/* OleTranslateAccelerator ordinal = 249, argument = 12 temporary */
static DWORD WINAPI OleTranslateAccelerator (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* OleUninitialize ordinal = 250, argument = 0 temporary */
static DWORD WINAPI OleUninitialize (VOID)
{
  return 0;
}


/* OpenOrCreateStream ordinal = 251, argument = 12 temporary */
static DWORD WINAPI OpenOrCreateStream (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* ProgIDFromCLSID ordinal = 252, argument = 8 temporary */
static DWORD WINAPI ProgIDFromCLSID (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* PropStgNameToFmtId ordinal = 253, argument = 8 temporary */
static DWORD WINAPI PropStgNameToFmtId (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* PropSysAllocString ordinal = 254, argument = 4 temporary */
static DWORD WINAPI PropSysAllocString (DWORD dwArgv0)
{
  return 0;
}


/* PropSysFreeString ordinal = 255, argument = 4 temporary */
static DWORD WINAPI PropSysFreeString (DWORD dwArgv0)
{
  return 0;
}


/* PropVariantChangeType ordinal = 1, argument = 0 temporary */
static DWORD WINAPI PropVariantChangeType (VOID)
{
  return 0;
}


/* PropVariantClear ordinal = 256, argument = 4 temporary */
static DWORD WINAPI PropVariantClear (DWORD dwArgv0)
{
  return 0;
}


/* PropVariantCopy ordinal = 257, argument = 8 temporary */
static DWORD WINAPI PropVariantCopy (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* ReadClassStg ordinal = 258, argument = 8 temporary */
static DWORD WINAPI ReadClassStg (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* ReadClassStm ordinal = 259, argument = 8 temporary */
static DWORD WINAPI ReadClassStm (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* ReadFmtUserTypeStg ordinal = 260, argument = 12 temporary */
static DWORD WINAPI ReadFmtUserTypeStg (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* ReadOleStg ordinal = 261, argument = 24 temporary */
static DWORD WINAPI ReadOleStg (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5)
{
  return 0;
}


/* ReadStringStream ordinal = 262, argument = 8 temporary */
static DWORD WINAPI ReadStringStream (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* RegisterDragDrop ordinal = 263, argument = 8 temporary */
static DWORD WINAPI RegisterDragDrop (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* ReleaseStgMedium ordinal = 264, argument = 4 temporary */
static DWORD WINAPI ReleaseStgMedium (DWORD dwArgv0)
{
  return 0;
}


/* RevokeDragDrop ordinal = 265, argument = 4 temporary */
static DWORD WINAPI RevokeDragDrop (DWORD dwArgv0)
{
  return 0;
}


/* SNB_UserFree ordinal = 266, argument = 8 temporary */
static DWORD WINAPI SNB_UserFree (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* SNB_UserMarshal ordinal = 267, argument = 12 temporary */
static DWORD WINAPI SNB_UserMarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* SNB_UserSize ordinal = 268, argument = 12 temporary */
static DWORD WINAPI SNB_UserSize (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* SNB_UserUnmarshal ordinal = 269, argument = 12 temporary */
static DWORD WINAPI SNB_UserUnmarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* STGMEDIUM_UserFree ordinal = 270, argument = 8 temporary */
static DWORD WINAPI STGMEDIUM_UserFree (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* STGMEDIUM_UserMarshal ordinal = 271, argument = 12 temporary */
static DWORD WINAPI STGMEDIUM_UserMarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* STGMEDIUM_UserSize ordinal = 272, argument = 12 temporary */
static DWORD WINAPI STGMEDIUM_UserSize (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* STGMEDIUM_UserUnmarshal ordinal = 273, argument = 12 temporary */
static DWORD WINAPI STGMEDIUM_UserUnmarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* SetConvertStg ordinal = 274, argument = 8 temporary */
static DWORD WINAPI SetConvertStg (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* SetDocumentBitStg ordinal = 275, argument = 8 temporary */
static DWORD WINAPI SetDocumentBitStg (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* SetErrorInfo ordinal = 276, argument = 0 temporary,conflict */
static DWORD WINAPI ole32_SetErrorInfo (VOID)
{
  return 0;
}


/* StgConvertPropertyToVariant ordinal = 2, argument = 16 temporary */
static DWORD WINAPI StgConvertPropertyToVariant (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* StgConvertVariantToProperty ordinal = 3, argument = 28 temporary */
static DWORD WINAPI StgConvertVariantToProperty (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5, DWORD dwArgv6)
{
  return 0;
}


/* StgCreateDocfile ordinal = 277, argument = 16 temporary */
static DWORD WINAPI StgCreateDocfile (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* StgCreateDocfileOnILockBytes ordinal = 278, argument = 16 temporary */
static DWORD WINAPI StgCreateDocfileOnILockBytes (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* StgCreatePropSetStg ordinal = 279, argument = 12 temporary */
static DWORD WINAPI StgCreatePropSetStg (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* StgCreatePropStg ordinal = 280, argument = 24 temporary */
static DWORD WINAPI StgCreatePropStg (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5)
{
  return 0;
}


/* StgCreateStorageEx ordinal = 281, argument = 32 temporary */
static DWORD WINAPI StgCreateStorageEx (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5, DWORD dwArgv6, DWORD dwArgv7)
{
  return 0;
}


/* StgGetIFillLockBytesOnFile ordinal = 282, argument = 8 temporary */
static DWORD WINAPI StgGetIFillLockBytesOnFile (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* StgGetIFillLockBytesOnILockBytes ordinal = 283, argument = 8 temporary */
static DWORD WINAPI StgGetIFillLockBytesOnILockBytes (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* StgIsStorageFile ordinal = 284, argument = 4 temporary */
static DWORD WINAPI StgIsStorageFile (DWORD dwArgv0)
{
  return 0;
}


/* StgIsStorageILockBytes ordinal = 285, argument = 4 temporary */
static DWORD WINAPI StgIsStorageILockBytes (DWORD dwArgv0)
{
  return 0;
}


/* StgOpenAsyncDocfileOnIFillLockBytes ordinal = 286, argument = 16 temporary */
static DWORD WINAPI StgOpenAsyncDocfileOnIFillLockBytes (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* StgOpenPropStg ordinal = 287, argument = 20 temporary */
static DWORD WINAPI StgOpenPropStg (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4)
{
  return 0;
}


/* StgOpenStorage ordinal = 288, argument = 24 temporary */
static DWORD WINAPI StgOpenStorage (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5)
{
  return 0;
}


/* StgOpenStorageEx ordinal = 289, argument = 32 temporary */
static DWORD WINAPI StgOpenStorageEx (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5, DWORD dwArgv6, DWORD dwArgv7)
{
  return 0;
}


/* StgOpenStorageOnHandle ordinal = 290, argument = 0 temporary */
static DWORD WINAPI StgOpenStorageOnHandle (VOID)
{
  return 0;
}


/* StgOpenStorageOnILockBytes ordinal = 291, argument = 24 temporary */
static DWORD WINAPI StgOpenStorageOnILockBytes (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4, DWORD dwArgv5)
{
  return 0;
}


/* StgPropertyLengthAsVariant ordinal = 4, argument = 16 temporary */
static DWORD WINAPI StgPropertyLengthAsVariant (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* StgSetTimes ordinal = 292, argument = 16 temporary */
static DWORD WINAPI StgSetTimes (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* StringFromCLSID ordinal = 293, argument = 8 temporary */
static DWORD WINAPI StringFromCLSID (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* StringFromGUID2 ordinal = 294, argument = 12 */
INT WINAPI StringFromGUID2 (REFGUID id, LPOLESTR str, INT cmax)
{
  return 0;
}


/* StringFromIID ordinal = 295, argument = 8 temporary */
static DWORD WINAPI StringFromIID (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* UpdateDCOMSettings ordinal = 296, argument = 0 temporary */
static DWORD WINAPI UpdateDCOMSettings (VOID)
{
  return 0;
}


/* UtConvertDvtd16toDvtd32 ordinal = 297, argument = 12 temporary */
static DWORD WINAPI UtConvertDvtd16toDvtd32 (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* UtConvertDvtd32toDvtd16 ordinal = 298, argument = 12 temporary */
static DWORD WINAPI UtConvertDvtd32toDvtd16 (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* UtGetDvtd16Info ordinal = 299, argument = 8 temporary */
static DWORD WINAPI UtGetDvtd16Info (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* UtGetDvtd32Info ordinal = 300, argument = 8 temporary */
static DWORD WINAPI UtGetDvtd32Info (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* WdtpInterfacePointer_UserFree ordinal = 5, argument = 4 temporary */
static DWORD WINAPI WdtpInterfacePointer_UserFree (DWORD dwArgv0)
{
  return 0;
}


/* WdtpInterfacePointer_UserMarshal ordinal = 6, argument = 20 temporary */
static DWORD WINAPI WdtpInterfacePointer_UserMarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4)
{
  return 0;
}


/* WdtpInterfacePointer_UserSize ordinal = 7, argument = 20 temporary */
static DWORD WINAPI WdtpInterfacePointer_UserSize (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3, DWORD dwArgv4)
{
  return 0;
}


/* WdtpInterfacePointer_UserUnmarshal ordinal = 8, argument = 16 temporary */
static DWORD WINAPI WdtpInterfacePointer_UserUnmarshal (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* WriteClassStg ordinal = 301, argument = 8 temporary */
static DWORD WINAPI WriteClassStg (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* WriteClassStm ordinal = 302, argument = 8 temporary */
static DWORD WINAPI WriteClassStm (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


/* WriteFmtUserTypeStg ordinal = 303, argument = 12 temporary */
static DWORD WINAPI WriteFmtUserTypeStg (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2)
{
  return 0;
}


/* WriteOleStg ordinal = 304, argument = 16 temporary */
static DWORD WINAPI WriteOleStg (DWORD dwArgv0, DWORD dwArgv1, DWORD dwArgv2, DWORD dwArgv3)
{
  return 0;
}


/* WriteStringStream ordinal = 305, argument = 8 temporary */
static DWORD WINAPI WriteStringStream (DWORD dwArgv0, DWORD dwArgv1)
{
  return 0;
}


W32LdrExport ole32_exports[] = {
{FALSE,   9, "BindMoniker",                           BindMoniker},
{FALSE,  10, "CLIPFORMAT_UserFree",                   CLIPFORMAT_UserFree},
{FALSE,  11, "CLIPFORMAT_UserMarshal",                CLIPFORMAT_UserMarshal},
{FALSE,  12, "CLIPFORMAT_UserSize",                   CLIPFORMAT_UserSize},
{FALSE,  13, "CLIPFORMAT_UserUnmarshal",              CLIPFORMAT_UserUnmarshal},
{FALSE,  14, "CLSIDFromOle1Class",                    CLSIDFromOle1Class},
{FALSE,  15, "CLSIDFromProgID",                       CLSIDFromProgID},
{FALSE,  16, "CLSIDFromProgIDEx",                     CLSIDFromProgIDEx},
{FALSE,  17, "CLSIDFromString",                       CLSIDFromString},
{FALSE,  18, "CoAddRefServerProcess",                 CoAddRefServerProcess},
{FALSE,  19, "CoAllowSetForegroundWindow",            CoAllowSetForegroundWindow},
{FALSE,  20, "CoBuildVersion",                        CoBuildVersion},
{FALSE,  21, "CoCancelCall",                          CoCancelCall},
{FALSE,  22, "CoCopyProxy",                           CoCopyProxy},
{FALSE,  23, "CoCreateFreeThreadedMarshaler",         CoCreateFreeThreadedMarshaler},
{FALSE,  24, "CoCreateGuid",                          CoCreateGuid},
{TRUE,   25, "CoCreateInstance",                      CoCreateInstance},
{FALSE,  26, "CoCreateInstanceEx",                    CoCreateInstanceEx},
{FALSE,  27, "CoCreateObjectInContext",               CoCreateObjectInContext},
{FALSE,  28, "CoDeactivateObject",                    CoDeactivateObject},
{FALSE,  29, "CoDisableCallCancellation",             CoDisableCallCancellation},
{FALSE,  30, "CoDisconnectObject",                    CoDisconnectObject},
{FALSE,  31, "CoDosDateTimeToFileTime",               CoDosDateTimeToFileTime},
{FALSE,  32, "CoEnableCallCancellation",              CoEnableCallCancellation},
{FALSE,  33, "CoFileTimeNow",                         CoFileTimeNow},
{FALSE,  34, "CoFileTimeToDosDateTime",               CoFileTimeToDosDateTime},
{FALSE,  35, "CoFreeAllLibraries",                    CoFreeAllLibraries},
{FALSE,  36, "CoFreeLibrary",                         CoFreeLibrary},
{TRUE,   37, "CoFreeUnusedLibraries",                 CoFreeUnusedLibraries},
{FALSE,  38, "CoFreeUnusedLibrariesEx",               CoFreeUnusedLibrariesEx},
{FALSE,  39, "CoGetApartmentID",                      CoGetApartmentID},
{FALSE,  40, "CoGetCallContext",                      CoGetCallContext},
{FALSE,  41, "CoGetCallerTID",                        CoGetCallerTID},
{FALSE,  42, "CoGetCancelObject",                     CoGetCancelObject},
{FALSE,  43, "CoGetClassObject",                      CoGetClassObject},
{FALSE,  44, "CoGetClassVersion",                     CoGetClassVersion},
{FALSE,  45, "CoGetContextToken",                     CoGetContextToken},
{FALSE,  46, "CoGetCurrentLogicalThreadId",           CoGetCurrentLogicalThreadId},
{FALSE,  47, "CoGetCurrentProcess",                   CoGetCurrentProcess},
{FALSE,  48, "CoGetInstanceFromFile",                 CoGetInstanceFromFile},
{FALSE,  49, "CoGetInstanceFromIStorage",             CoGetInstanceFromIStorage},
{FALSE,  50, "CoGetInterfaceAndReleaseStream",        CoGetInterfaceAndReleaseStream},
{FALSE,  51, "CoGetMalloc",                           CoGetMalloc},
{FALSE,  52, "CoGetMarshalSizeMax",                   CoGetMarshalSizeMax},
{FALSE,  53, "CoGetObject",                           CoGetObject},
{FALSE,  54, "CoGetObjectContext",                    CoGetObjectContext},
{FALSE,  55, "CoGetPSClsid",                          CoGetPSClsid},
{FALSE,  56, "CoGetStandardMarshal",                  CoGetStandardMarshal},
{FALSE,  57, "CoGetState",                            CoGetState},
{FALSE,  58, "CoGetStdMarshalEx",                     CoGetStdMarshalEx},
{FALSE,  59, "CoGetTreatAsClass",                     CoGetTreatAsClass},
{FALSE,  60, "CoImpersonateClient",                   CoImpersonateClient},
{TRUE,   61, "CoInitialize",                          CoInitialize},
{FALSE,  62, "CoInitializeEx",                        CoInitializeEx},
{FALSE,  63, "CoInitializeSecurity",                  CoInitializeSecurity},
{FALSE,  64, "CoInitializeWOW",                       CoInitializeWOW},
{FALSE,  65, "CoInstall",                             CoInstall},
{FALSE,  66, "CoIsHandlerConnected",                  CoIsHandlerConnected},
{FALSE,  67, "CoIsOle1Class",                         CoIsOle1Class},
{FALSE,  68, "CoLoadLibrary",                         CoLoadLibrary},
{FALSE,  69, "CoLockObjectExternal",                  CoLockObjectExternal},
{FALSE,  70, "CoMarshalHresult",                      CoMarshalHresult},
{FALSE,  71, "CoMarshalInterThreadInterfaceInStream", CoMarshalInterThreadInterfaceInStream},
{FALSE,  72, "CoMarshalInterface",                    CoMarshalInterface},
{FALSE,  73, "CoQueryAuthenticationServices",         CoQueryAuthenticationServices},
{FALSE,  74, "CoQueryClientBlanket",                  CoQueryClientBlanket},
{FALSE,  75, "CoQueryProxyBlanket",                   CoQueryProxyBlanket},
{FALSE,  76, "CoQueryReleaseObject",                  CoQueryReleaseObject},
{FALSE,  77, "CoReactivateObject",                    CoReactivateObject},
{FALSE,  78, "CoRegisterChannelHook",                 CoRegisterChannelHook},
{FALSE,  79, "CoRegisterClassObject",                 CoRegisterClassObject},
{FALSE,  80, "CoRegisterMallocSpy",                   CoRegisterMallocSpy},
{FALSE,  81, "CoRegisterMessageFilter",               CoRegisterMessageFilter},
{FALSE,  82, "CoRegisterPSClsid",                     CoRegisterPSClsid},
{FALSE,  83, "CoRegisterSurrogate",                   CoRegisterSurrogate},
{FALSE,  84, "CoRegisterSurrogateEx",                 CoRegisterSurrogateEx},
{FALSE,  85, "CoReleaseMarshalData",                  CoReleaseMarshalData},
{FALSE,  86, "CoReleaseServerProcess",                CoReleaseServerProcess},
{FALSE,  87, "CoResumeClassObjects",                  CoResumeClassObjects},
{FALSE,  88, "CoRevertToSelf",                        CoRevertToSelf},
{FALSE,  89, "CoRevokeClassObject",                   CoRevokeClassObject},
{FALSE,  90, "CoRevokeMallocSpy",                     CoRevokeMallocSpy},
{FALSE,  91, "CoSetCancelObject",                     CoSetCancelObject},
{FALSE,  92, "CoSetProxyBlanket",                     CoSetProxyBlanket},
{FALSE,  93, "CoSetState",                            CoSetState},
{FALSE,  94, "CoSuspendClassObjects",                 CoSuspendClassObjects},
{FALSE,  95, "CoSwitchCallContext",                   CoSwitchCallContext},
{TRUE,   96, "CoTaskMemAlloc",                        CoTaskMemAlloc},
{TRUE,   97, "CoTaskMemFree",                         CoTaskMemFree},
{FALSE,  98, "CoTaskMemRealloc",                      CoTaskMemRealloc},
{FALSE,  99, "CoTestCancel",                          CoTestCancel},
{FALSE, 100, "CoTreatAsClass",                        CoTreatAsClass},
{TRUE,  101, "CoUninitialize",                        CoUninitialize},
{FALSE, 102, "CoUnloadingWOW",                        CoUnloadingWOW},
{FALSE, 103, "CoUnmarshalHresult",                    CoUnmarshalHresult},
{FALSE, 104, "CoUnmarshalInterface",                  CoUnmarshalInterface},
{FALSE, 105, "CoWaitForMultipleHandles",              CoWaitForMultipleHandles},
{FALSE, 106, "CreateAntiMoniker",                     CreateAntiMoniker},
{FALSE, 107, "CreateBindCtx",                         CreateBindCtx},
{FALSE, 108, "CreateClassMoniker",                    CreateClassMoniker},
{FALSE, 109, "CreateDataAdviseHolder",                CreateDataAdviseHolder},
{FALSE, 110, "CreateDataCache",                       CreateDataCache},
{FALSE, 111, "CreateErrorInfo",                       ole32_CreateErrorInfo},
{FALSE, 112, "CreateFileMoniker",                     CreateFileMoniker},
{FALSE, 113, "CreateGenericComposite",                CreateGenericComposite},
{FALSE, 114, "CreateILockBytesOnHGlobal",             CreateILockBytesOnHGlobal},
{FALSE, 115, "CreateItemMoniker",                     CreateItemMoniker},
{FALSE, 116, "CreateObjrefMoniker",                   CreateObjrefMoniker},
{FALSE, 117, "CreateOleAdviseHolder",                 CreateOleAdviseHolder},
{FALSE, 118, "CreatePointerMoniker",                  CreatePointerMoniker},
{FALSE, 119, "CreateStdProgressIndicator",            CreateStdProgressIndicator},
{FALSE, 120, "CreateStreamOnHGlobal",                 CreateStreamOnHGlobal},
{FALSE, 121, "DcomChannelSetHResult",                 DcomChannelSetHResult},
{FALSE, 122, "DllDebugObjectRPCHook",                 DllDebugObjectRPCHook},
{FALSE, 123, "DllGetClassObject",                     ole32_DllGetClassObject},
{FALSE, 124, "DllGetClassObjectWOW",                  DllGetClassObjectWOW},
{FALSE, 125, "DllRegisterServer",                     ole32_DllRegisterServer},
{FALSE, 126, "DoDragDrop",                            DoDragDrop},
{FALSE, 127, "EnableHookObject",                      EnableHookObject},
{FALSE, 128, "FmtIdToPropStgName",                    FmtIdToPropStgName},
{FALSE, 129, "FreePropVariantArray",                  FreePropVariantArray},
{FALSE, 130, "GetClassFile",                          GetClassFile},
{FALSE, 131, "GetConvertStg",                         GetConvertStg},
{FALSE, 132, "GetDocumentBitStg",                     GetDocumentBitStg},
{FALSE, 133, "GetErrorInfo",                          ole32_GetErrorInfo},
{FALSE, 134, "GetHGlobalFromILockBytes",              GetHGlobalFromILockBytes},
{FALSE, 135, "GetHGlobalFromStream",                  GetHGlobalFromStream},
{FALSE, 136, "GetHookInterface",                      GetHookInterface},
{FALSE, 137, "GetRunningObjectTable",                 GetRunningObjectTable},
{FALSE, 138, "HACCEL_UserFree",                       HACCEL_UserFree},
{FALSE, 139, "HACCEL_UserMarshal",                    HACCEL_UserMarshal},
{FALSE, 140, "HACCEL_UserSize",                       HACCEL_UserSize},
{FALSE, 141, "HACCEL_UserUnmarshal",                  HACCEL_UserUnmarshal},
{FALSE, 142, "HBITMAP_UserFree",                      HBITMAP_UserFree},
{FALSE, 143, "HBITMAP_UserMarshal",                   HBITMAP_UserMarshal},
{FALSE, 144, "HBITMAP_UserSize",                      HBITMAP_UserSize},
{FALSE, 145, "HBITMAP_UserUnmarshal",                 HBITMAP_UserUnmarshal},
{FALSE, 146, "HBRUSH_UserFree",                       HBRUSH_UserFree},
{FALSE, 147, "HBRUSH_UserMarshal",                    HBRUSH_UserMarshal},
{FALSE, 148, "HBRUSH_UserSize",                       HBRUSH_UserSize},
{FALSE, 149, "HBRUSH_UserUnmarshal",                  HBRUSH_UserUnmarshal},
{FALSE, 150, "HDC_UserFree",                          HDC_UserFree},
{FALSE, 151, "HDC_UserMarshal",                       HDC_UserMarshal},
{FALSE, 152, "HDC_UserSize",                          HDC_UserSize},
{FALSE, 153, "HDC_UserUnmarshal",                     HDC_UserUnmarshal},
{FALSE, 154, "HENHMETAFILE_UserFree",                 HENHMETAFILE_UserFree},
{FALSE, 155, "HENHMETAFILE_UserMarshal",              HENHMETAFILE_UserMarshal},
{FALSE, 156, "HENHMETAFILE_UserSize",                 HENHMETAFILE_UserSize},
{FALSE, 157, "HENHMETAFILE_UserUnmarshal",            HENHMETAFILE_UserUnmarshal},
{FALSE, 158, "HGLOBAL_UserFree",                      HGLOBAL_UserFree},
{FALSE, 159, "HGLOBAL_UserMarshal",                   HGLOBAL_UserMarshal},
{FALSE, 160, "HGLOBAL_UserSize",                      HGLOBAL_UserSize},
{FALSE, 161, "HGLOBAL_UserUnmarshal",                 HGLOBAL_UserUnmarshal},
{FALSE, 162, "HICON_UserFree",                        HICON_UserFree},
{FALSE, 163, "HICON_UserMarshal",                     HICON_UserMarshal},
{FALSE, 164, "HICON_UserSize",                        HICON_UserSize},
{FALSE, 165, "HICON_UserUnmarshal",                   HICON_UserUnmarshal},
{FALSE, 166, "HMENU_UserFree",                        HMENU_UserFree},
{FALSE, 167, "HMENU_UserMarshal",                     HMENU_UserMarshal},
{FALSE, 168, "HMENU_UserSize",                        HMENU_UserSize},
{FALSE, 169, "HMENU_UserUnmarshal",                   HMENU_UserUnmarshal},
{FALSE, 170, "HMETAFILEPICT_UserFree",                HMETAFILEPICT_UserFree},
{FALSE, 171, "HMETAFILEPICT_UserMarshal",             HMETAFILEPICT_UserMarshal},
{FALSE, 172, "HMETAFILEPICT_UserSize",                HMETAFILEPICT_UserSize},
{FALSE, 173, "HMETAFILEPICT_UserUnmarshal",           HMETAFILEPICT_UserUnmarshal},
{FALSE, 174, "HMETAFILE_UserFree",                    HMETAFILE_UserFree},
{FALSE, 175, "HMETAFILE_UserMarshal",                 HMETAFILE_UserMarshal},
{FALSE, 176, "HMETAFILE_UserSize",                    HMETAFILE_UserSize},
{FALSE, 177, "HMETAFILE_UserUnmarshal",               HMETAFILE_UserUnmarshal},
{FALSE, 178, "HPALETTE_UserFree",                     HPALETTE_UserFree},
{FALSE, 179, "HPALETTE_UserMarshal",                  HPALETTE_UserMarshal},
{FALSE, 180, "HPALETTE_UserSize",                     HPALETTE_UserSize},
{FALSE, 181, "HPALETTE_UserUnmarshal",                HPALETTE_UserUnmarshal},
{FALSE, 182, "HWND_UserFree",                         HWND_UserFree},
{FALSE, 183, "HWND_UserMarshal",                      HWND_UserMarshal},
{FALSE, 184, "HWND_UserSize",                         HWND_UserSize},
{FALSE, 185, "HWND_UserUnmarshal",                    HWND_UserUnmarshal},
{FALSE, 186, "HkOleRegisterObject",                   HkOleRegisterObject},
{FALSE, 187, "IIDFromString",                         IIDFromString},
{FALSE, 188, "IsAccelerator",                         IsAccelerator},
{FALSE, 189, "IsEqualGUID",                           IsEqualGUID},
{FALSE, 190, "IsValidIid",                            IsValidIid},
{FALSE, 191, "IsValidInterface",                      IsValidInterface},
{FALSE, 192, "IsValidPtrIn",                          IsValidPtrIn},
{FALSE, 193, "IsValidPtrOut",                         IsValidPtrOut},
{FALSE, 194, "MkParseDisplayName",                    MkParseDisplayName},
{FALSE, 195, "MonikerCommonPrefixWith",               MonikerCommonPrefixWith},
{FALSE, 196, "MonikerRelativePathTo",                 MonikerRelativePathTo},
{FALSE, 197, "OleBuildVersion",                       OleBuildVersion},
{FALSE, 198, "OleConvertIStorageToOLESTREAM",         OleConvertIStorageToOLESTREAM},
{FALSE, 199, "OleConvertIStorageToOLESTREAMEx",       OleConvertIStorageToOLESTREAMEx},
{FALSE, 200, "OleConvertOLESTREAMToIStorage",         OleConvertOLESTREAMToIStorage},
{FALSE, 201, "OleConvertOLESTREAMToIStorageEx",       OleConvertOLESTREAMToIStorageEx},
{FALSE, 202, "OleCreate",                             OleCreate},
{FALSE, 203, "OleCreateDefaultHandler",               OleCreateDefaultHandler},
{FALSE, 204, "OleCreateEmbeddingHelper",              OleCreateEmbeddingHelper},
{FALSE, 205, "OleCreateEx",                           OleCreateEx},
{FALSE, 206, "OleCreateFromData",                     OleCreateFromData},
{FALSE, 207, "OleCreateFromDataEx",                   OleCreateFromDataEx},
{FALSE, 208, "OleCreateFromFile",                     OleCreateFromFile},
{FALSE, 209, "OleCreateFromFileEx",                   OleCreateFromFileEx},
{FALSE, 210, "OleCreateLink",                         OleCreateLink},
{FALSE, 211, "OleCreateLinkEx",                       OleCreateLinkEx},
{FALSE, 212, "OleCreateLinkFromData",                 OleCreateLinkFromData},
{FALSE, 213, "OleCreateLinkFromDataEx",               OleCreateLinkFromDataEx},
{FALSE, 214, "OleCreateLinkToFile",                   OleCreateLinkToFile},
{FALSE, 215, "OleCreateLinkToFileEx",                 OleCreateLinkToFileEx},
{FALSE, 216, "OleCreateMenuDescriptor",               OleCreateMenuDescriptor},
{FALSE, 217, "OleCreateStaticFromData",               OleCreateStaticFromData},
{FALSE, 218, "OleDestroyMenuDescriptor",              OleDestroyMenuDescriptor},
{FALSE, 219, "OleDoAutoConvert",                      OleDoAutoConvert},
{FALSE, 220, "OleDraw",                               OleDraw},
{FALSE, 221, "OleDuplicateData",                      OleDuplicateData},
{FALSE, 222, "OleFlushClipboard",                     OleFlushClipboard},
{FALSE, 223, "OleGetAutoConvert",                     OleGetAutoConvert},
{FALSE, 224, "OleGetClipboard",                       OleGetClipboard},
{FALSE, 225, "OleGetIconOfClass",                     OleGetIconOfClass},
{FALSE, 226, "OleGetIconOfFile",                      OleGetIconOfFile},
{FALSE, 227, "OleInitialize",                         OleInitialize},
{FALSE, 228, "OleInitializeWOW",                      OleInitializeWOW},
{FALSE, 229, "OleIsCurrentClipboard",                 OleIsCurrentClipboard},
{FALSE, 230, "OleIsRunning",                          OleIsRunning},
{FALSE, 231, "OleLoad",                               OleLoad},
{FALSE, 232, "OleLoadFromStream",                     OleLoadFromStream},
{FALSE, 233, "OleLockRunning",                        OleLockRunning},
{FALSE, 234, "OleMetafilePictFromIconAndLabel",       OleMetafilePictFromIconAndLabel},
{FALSE, 235, "OleNoteObjectVisible",                  OleNoteObjectVisible},
{FALSE, 236, "OleQueryCreateFromData",                OleQueryCreateFromData},
{FALSE, 237, "OleQueryLinkFromData",                  OleQueryLinkFromData},
{FALSE, 238, "OleRegEnumFormatEtc",                   OleRegEnumFormatEtc},
{FALSE, 239, "OleRegEnumVerbs",                       OleRegEnumVerbs},
{FALSE, 240, "OleRegGetMiscStatus",                   OleRegGetMiscStatus},
{FALSE, 241, "OleRegGetUserType",                     OleRegGetUserType},
{FALSE, 242, "OleRun",                                OleRun},
{FALSE, 243, "OleSave",                               OleSave},
{FALSE, 244, "OleSaveToStream",                       OleSaveToStream},
{FALSE, 245, "OleSetAutoConvert",                     OleSetAutoConvert},
{FALSE, 246, "OleSetClipboard",                       OleSetClipboard},
{FALSE, 247, "OleSetContainedObject",                 OleSetContainedObject},
{FALSE, 248, "OleSetMenuDescriptor",                  OleSetMenuDescriptor},
{FALSE, 249, "OleTranslateAccelerator",               OleTranslateAccelerator},
{FALSE, 250, "OleUninitialize",                       OleUninitialize},
{FALSE, 251, "OpenOrCreateStream",                    OpenOrCreateStream},
{FALSE, 252, "ProgIDFromCLSID",                       ProgIDFromCLSID},
{FALSE, 253, "PropStgNameToFmtId",                    PropStgNameToFmtId},
{FALSE, 254, "PropSysAllocString",                    PropSysAllocString},
{FALSE, 255, "PropSysFreeString",                     PropSysFreeString},
{FALSE,   1, "PropVariantChangeType",                 PropVariantChangeType},
{FALSE, 256, "PropVariantClear",                      PropVariantClear},
{FALSE, 257, "PropVariantCopy",                       PropVariantCopy},
{FALSE, 258, "ReadClassStg",                          ReadClassStg},
{FALSE, 259, "ReadClassStm",                          ReadClassStm},
{FALSE, 260, "ReadFmtUserTypeStg",                    ReadFmtUserTypeStg},
{FALSE, 261, "ReadOleStg",                            ReadOleStg},
{FALSE, 262, "ReadStringStream",                      ReadStringStream},
{FALSE, 263, "RegisterDragDrop",                      RegisterDragDrop},
{FALSE, 264, "ReleaseStgMedium",                      ReleaseStgMedium},
{FALSE, 265, "RevokeDragDrop",                        RevokeDragDrop},
{FALSE, 266, "SNB_UserFree",                          SNB_UserFree},
{FALSE, 267, "SNB_UserMarshal",                       SNB_UserMarshal},
{FALSE, 268, "SNB_UserSize",                          SNB_UserSize},
{FALSE, 269, "SNB_UserUnmarshal",                     SNB_UserUnmarshal},
{FALSE, 270, "STGMEDIUM_UserFree",                    STGMEDIUM_UserFree},
{FALSE, 271, "STGMEDIUM_UserMarshal",                 STGMEDIUM_UserMarshal},
{FALSE, 272, "STGMEDIUM_UserSize",                    STGMEDIUM_UserSize},
{FALSE, 273, "STGMEDIUM_UserUnmarshal",               STGMEDIUM_UserUnmarshal},
{FALSE, 274, "SetConvertStg",                         SetConvertStg},
{FALSE, 275, "SetDocumentBitStg",                     SetDocumentBitStg},
{FALSE, 276, "SetErrorInfo",                          ole32_SetErrorInfo},
{FALSE,   2, "StgConvertPropertyToVariant",           StgConvertPropertyToVariant},
{FALSE,   3, "StgConvertVariantToProperty",           StgConvertVariantToProperty},
{FALSE, 277, "StgCreateDocfile",                      StgCreateDocfile},
{FALSE, 278, "StgCreateDocfileOnILockBytes",          StgCreateDocfileOnILockBytes},
{FALSE, 279, "StgCreatePropSetStg",                   StgCreatePropSetStg},
{FALSE, 280, "StgCreatePropStg",                      StgCreatePropStg},
{FALSE, 281, "StgCreateStorageEx",                    StgCreateStorageEx},
{FALSE, 282, "StgGetIFillLockBytesOnFile",            StgGetIFillLockBytesOnFile},
{FALSE, 283, "StgGetIFillLockBytesOnILockBytes",      StgGetIFillLockBytesOnILockBytes},
{FALSE, 284, "StgIsStorageFile",                      StgIsStorageFile},
{FALSE, 285, "StgIsStorageILockBytes",                StgIsStorageILockBytes},
{FALSE, 286, "StgOpenAsyncDocfileOnIFillLockBytes",   StgOpenAsyncDocfileOnIFillLockBytes},
{FALSE, 287, "StgOpenPropStg",                        StgOpenPropStg},
{FALSE, 288, "StgOpenStorage",                        StgOpenStorage},
{FALSE, 289, "StgOpenStorageEx",                      StgOpenStorageEx},
{FALSE, 290, "StgOpenStorageOnHandle",                StgOpenStorageOnHandle},
{FALSE, 291, "StgOpenStorageOnILockBytes",            StgOpenStorageOnILockBytes},
{FALSE,   4, "StgPropertyLengthAsVariant",            StgPropertyLengthAsVariant},
{FALSE, 292, "StgSetTimes",                           StgSetTimes},
{FALSE, 293, "StringFromCLSID",                       StringFromCLSID},
{TRUE,  294, "StringFromGUID2",                       StringFromGUID2},
{FALSE, 295, "StringFromIID",                         StringFromIID},
{FALSE, 296, "UpdateDCOMSettings",                    UpdateDCOMSettings},
{FALSE, 297, "UtConvertDvtd16toDvtd32",               UtConvertDvtd16toDvtd32},
{FALSE, 298, "UtConvertDvtd32toDvtd16",               UtConvertDvtd32toDvtd16},
{FALSE, 299, "UtGetDvtd16Info",                       UtGetDvtd16Info},
{FALSE, 300, "UtGetDvtd32Info",                       UtGetDvtd32Info},
{FALSE,   5, "WdtpInterfacePointer_UserFree",         WdtpInterfacePointer_UserFree},
{FALSE,   6, "WdtpInterfacePointer_UserMarshal",      WdtpInterfacePointer_UserMarshal},
{FALSE,   7, "WdtpInterfacePointer_UserSize",         WdtpInterfacePointer_UserSize},
{FALSE,   8, "WdtpInterfacePointer_UserUnmarshal",    WdtpInterfacePointer_UserUnmarshal},
{FALSE, 301, "WriteClassStg",                         WriteClassStg},
{FALSE, 302, "WriteClassStm",                         WriteClassStm},
{FALSE, 303, "WriteFmtUserTypeStg",                   WriteFmtUserTypeStg},
{FALSE, 304, "WriteOleStg",                           WriteOleStg},
{FALSE, 305, "WriteStringStream",                     WriteStringStream},
{FALSE,   0, NULL,                                    NULL}};
